==> qttranslations-everywhere-src-6.6.2.tar.xz: qttranslations-everywhere-src-6.6.2/translations/qt_help_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr_TR">
<context>
    <name>QHelp</name>
    <message>
        <source>Untitled</source>
        <translation>Başlıksız</translation>
    </message>
</context>
<context>
    <name>QHelpCollectionHandler</name>
    <message>
        <source>The collection file &quot;%1&quot; is not set up yet.</source>
        <translation>&quot;%1&quot; koleksiyon dosyası henüz oluşturulmadı.</translation>
    </message>
    <message>
        <source>Cannot load sqlite database driver.</source>
        <translation>Sqlite veritabanı sürücüsü yüklenemiyor.</translation>
    </message>
    <message>
        <source>Cannot open collection file: %1</source>
        <translation>Koleksiyon dosyası açılamıyor: %1</translation>
    </message>
    <message>
        <source>Cannot create tables in file %1.</source>
        <translation>%1 dosyasında tablolar oluşturulamıyor.</translation>
    </message>
    <message>
        <source>Cannot create index tables in file %1.</source>
        <translation>%1 dosyasında indeks tabloları oluşturulamıyor.</translation>
    </message>
    <message>
        <source>Cannot register index tables in file %1.</source>
        <translation>%1 dosyasında indeks tabloları kaydedilemiyor.</translation>
    </message>
    <message>
        <source>Cannot unregister index tables in file %1.</source>
        <translation>%1 dosyasındaki indeks tablolarının kaydı silinemiyor.</translation>
    </message>
    <message>
        <source>The collection file &quot;%1&quot; already exists.</source>
        <translation>&quot;%1&quot; koleksiyon dosyası halihazırda var.</translation>
    </message>
    <message>
        <source>Cannot create directory: %1</source>
        <translation>Dizin oluşturulamıyor: %1</translation>
    </message>
    <message>
        <source>Cannot copy collection file: %1</source>
        <translation>Koleksiyon dosyası kopyalanamıyor: %1</translation>
    </message>
    <message>
        <source>Unknown filter &quot;%1&quot;.</source>
        <translation>Bilinmeyen süzgeç &quot;%1&quot;.</translation>
    </message>
    <message>
        <source>Cannot register filter %1.</source>
        <translation>%1 süzgeci kaydedilemiyor.</translation>
    </message>
    <message>
        <source>Cannot open documentation file %1.</source>
        <translation>%1 belgelendirme dosyası açılamıyor.</translation>
    </message>
    <message>
        <source>Invalid documentation file &quot;%1&quot;.</source>
        <translation>Geçersiz belgelendirme dosyası &quot;%1&quot;.</translation>
    </message>
    <message>
        <source>The namespace %1 was not registered.</source>
        <translation>%1 ad alanı kayıt edilmedi.</translation>
    </message>
    <message>
        <source>Namespace %1 already exists.</source>
        <translation>%1 ad alanı halihazırda var.</translation>
    </message>
    <message>
        <source>Cannot register namespace &quot;%1&quot;.</source>
        <translation>&quot;%1&quot; ad alanı kayıt edilemiyor.</translation>
    </message>
    <message>
        <source>Cannot register virtual folder &apos;%1&apos;.</source>
        <translation>&apos;%1&apos; sanal klasörü kayıt edilemiyor.</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Sürüm %1</translation>
    </message>
</context>
<context>
    <name>QHelpDBReader</name>
    <message>
        <source>Cannot open database &quot;%1&quot; &quot;%2&quot;: %3</source>
        <extracomment>The placeholders are: %1 - The name of the database which cannot be opened %2 - The unique id for the connection %3 - The actual error string</extracomment>
        <translation>&quot;%1&quot; &quot;%2&quot; veritabanı açılamıyor: %3</translation>
    </message>
</context>
<context>
    <name>QHelpSearchQueryWidget</name>
    <message>
        <source>Search for:</source>
        <translation>Ara:</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Ara</translation>
    </message>
    <message>
        <source>Previous search</source>
        <translation>Önceki arama</translation>
    </message>
    <message>
        <source>Next search</source>
        <translation>Sonraki arama</translation>
    </message>
</context>
<context>
    <name>QHelpSearchResultWidget</name>
    <message numerus="yes">
        <source>%1 - %2 of %n Hits</source>
        <translation>
            <numerusform>%1 - %2/%n sonuç</numerusform>
        </translation>
    </message>
    <message>
        <source>0 - 0 of 0 Hits</source>
        <translation>0 - 0/0 sonuç</translation>
    </message>
</context>
<context>
    <name>QResultWidget</name>
    <message>
        <source>Search Results</source>
        <translation>Arama Sonuçları</translation>
    </message>
    <message>
        <source>Note:</source>
        <translation>Not:</translation>
    </message>
    <message>
        <source>The search results may not be complete since the documentation is still being indexed.</source>
        <translation>Belgelendirme hâlâ indekslendiğinden arama sonuçları tam olmayabilir.</translation>
    </message>
    <message>
        <source>Your search did not match any documents.</source>
        <translation>Aramanız hiçbir belgeyle eşleşmedi.</translation>
    </message>
    <message>
        <source>(The reason for this might be that the documentation is still being indexed.)</source>
        <translation>(Bunun nedeni, belgelendirmenin hâlâ indekslenmesidir.)</translation>
    </message>
</context>
<context>
    <name>fulltextsearch::qt::QHelpSearchIndexWriter</name>
    <message>
        <source>Cannot open database &quot;%1&quot; using connection &quot;%2&quot;: %3</source>
        <translation>&quot;%2&quot; bağlantısı kullanılarak &quot;%1&quot; veritabanı açılamıyor: %3</translation>
    </message>
</context>
<context>
    <name>FilterNameDialogClass</name>
    <message>
        <source>Add Filter</source>
        <translation>Süzgeç Ekle</translation>
    </message>
    <message>
        <source>Filter Name:</source>
        <translation>Süzgeç adı:</translation>
    </message>
</context>
<context>
    <name>QHelpFilterSettingsWidget</name>
    <message>
        <source>Form</source>
        <translation>Form</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Süzgeç</translation>
    </message>
    <message>
        <source>Components</source>
        <translation>Bileşenler</translation>
    </message>
    <message>
        <source>Versions</source>
        <translation>Sürümler</translation>
    </message>
    <message>
        <source>Add...</source>
        <translation>Ekle...</translation>
    </message>
    <message>
        <source>Rename...</source>
        <translation>Yeniden Adlandır...</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Kaldır</translation>
    </message>
    <message>
        <source>Add Filter</source>
        <translation>Süzgeç Ekle</translation>
    </message>
    <message>
        <source>New Filter</source>
        <translation>Yeni Süzgeç</translation>
    </message>
    <message>
        <source>Rename Filter</source>
        <translation>Süzgeci Yeniden Adlandır</translation>
    </message>
    <message>
        <source>Remove Filter</source>
        <translation>Süzgeci Kaldır</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the &quot;%1&quot; filter?</source>
        <translation>&quot;%1&quot; süzgecini kaldırmak istediğinizden emin misiniz?</translation>
    </message>
    <message>
        <source>Filter Exists</source>
        <translation>Süzgeç Var</translation>
    </message>
    <message>
        <source>The filter &quot;%1&quot; already exists.</source>
        <translation>&quot;%1&quot; süzgeci halihazırda var.</translation>
    </message>
    <message>
        <source>No Component</source>
        <translation>Bileşen Yok</translation>
    </message>
    <message>
        <source>Invalid Component</source>
        <translation>Geçersiz Bileşen</translation>
    </message>
    <message>
        <source>No Version</source>
        <translation>Sürüm Yok</translation>
    </message>
    <message>
        <source>Invalid Version</source>
        <translation>Geçersiz Sürüm</translation>
    </message>
</context>
<context>
    <name>QOptionsWidget</name>
    <message>
        <source>No Option</source>
        <translation>Seçenek Yok</translation>
    </message>
    <message>
        <source>Invalid Option</source>
        <translation>Geçersiz Seçenek</translation>
    </message>
</context>
</TS>

==> qttranslations-everywhere-src-6.10.1.tar.xz: qttranslations-everywhere-src-6.10.1/translations/qt_help_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr_TR">
<context>
    <name>QHelp</name>
    <message>
        <source>Untitled</source>
        <translation>Başlıksız</translation>
    </message>
</context>
<context>
    <name>QHelpCollectionHandler</name>
    <message>
        <source>The collection file &quot;%1&quot; is not set up yet.</source>
        <translation>“%1” koleksiyon dosyası henüz oluşturulmadı.</translation>
    </message>
    <message>
        <source>Cannot load sqlite database driver.</source>
        <translation>Sqlite veritabanı sürücüsü yüklenemiyor.</translation>
    </message>
    <message>
        <source>Cannot open collection file: %1</source>
        <translation>Koleksiyon dosyası açılamıyor: %1</translation>
    </message>
    <message>
        <source>Cannot create tables in file %1.</source>
        <translation>%1 dosyasında tablolar oluşturulamıyor.</translation>
    </message>
    <message>
        <source>Cannot create index tables in file %1.</source>
        <translation>%1 dosyasında indeks tabloları oluşturulamıyor.</translation>
    </message>
    <message>
        <source>Cannot register index tables in file %1.</source>
        <translation>%1 dosyasında indeks tabloları kaydedilemiyor.</translation>
    </message>
    <message>
        <source>Cannot unregister index tables in file %1.</source>
        <translation>%1 dosyasındaki indeks tablolarının kaydı silinemiyor.</translation>
    </message>
    <message>
        <source>The collection file &quot;%1&quot; already exists.</source>
        <translation>“%1” koleksiyon dosyası halihazırda var.</translation>
    </message>
    <message>
        <source>Cannot create directory: %1</source>
        <translation>Dizin oluşturulamıyor: %1</translation>
    </message>
    <message>
        <source>Cannot copy collection file: %1</source>
        <translation>Koleksiyon dosyası kopyalanamıyor: %1</translation>
    </message>
    <message>
        <source>Unknown filter &quot;%1&quot;.</source>
        <translation>Bilinmeyen süzgeç “%1”.</translation>
    </message>
    <message>
        <source>Cannot register filter %1.</source>
        <translation>%1 süzgeci kaydedilemiyor.</translation>
    </message>
    <message>
        <source>Cannot open documentation file %1.</source>
        <translation>%1 belgelendirme dosyası açılamıyor.</translation>
    </message>
    <message>
        <source>Invalid documentation file &quot;%1&quot;.</source>
        <translation>Geçersiz belgelendirme dosyası “%1”.</translation>
    </message>
    <message>
        <source>The namespace %1 was not registered.</source>
        <translation>%1 ad alanı kayıt edilmedi.</translation>
    </message>
    <message>
        <source>Namespace %1 already exists.</source>
        <translation>%1 ad alanı halihazırda var.</translation>
    </message>
    <message>
        <source>Cannot register namespace &quot;%1&quot;.</source>
        <translation>“%1” ad alanı kayıt edilemiyor.</translation>
    </message>
    <message>
        <source>Cannot register virtual folder &apos;%1&apos;.</source>
        <translation>“%1” sanal klasörü kayıt edilemiyor.</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Sürüm %1</translation>
    </message>
</context>
<context>
    <name>QHelpDBReader</name>
    <message>
        <source>Cannot open database &quot;%1&quot; &quot;%2&quot;: %3</source>
        <extracomment>The placeholders are: %1 - The name of the database which cannot be opened %2 - The unique id for the connection %3 - The actual error string</extracomment>
        <translation>“%1” “%2” veritabanı açılamıyor: %3</translation>
    </message>
</context>
<context>
    <name>QHelpSearchQueryWidget</name>
    <message>
        <source>Search for:</source>
        <translation>Ara:</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Ara</translation>
    </message>
    <message>
        <source>Previous search</source>
        <translation>Önceki arama</translation>
    </message>
    <message>
        <source>Next search</source>
        <translation>Sonraki arama</translation>
    </message>
</context>
<context>
    <name>QHelpSearchResultWidget</name>
    <message numerus="yes">
        <source>%1 - %2 of %n Hits</source>
        <translation>
            <numerusform>%1 — %2/%n sonuç</numerusform>
        </translation>
    </message>
    <message>
        <source>0 - 0 of 0 Hits</source>
        <translation>0 — 0/0 sonuç</translation>
    </message>
</context>
<context>
    <name>QResultWidget</name>
    <message>
        <source>Search Results</source>
        <translation>Arama Sonuçları</translation>
    </message>
    <message>
        <source>Note:</source>
        <translation>Not:</translation>
    </message>
    <message>
        <source>The search results may not be complete since the documentation is still being indexed.</source>
        <translation>Belgelendirme hâlâ indekslendiğinden arama sonuçları tam olmayabilir.</translation>
    </message>
    <message>
        <source>Your search did not match any documents.</source>
        <translation>Aramanız hiçbir belgeyle eşleşmedi.</translation>
    </message>
    <message>
        <source>(The reason for this might be that the documentation is still being indexed.)</source>
        <translation>(Bunun nedeni, belgelendirmenin hâlâ indekslenmesidir.)</translation>
    </message>
</context>
<context>
    <name>fulltextsearch::qt::QHelpSearchIndexWriter</name>
    <message>
        <source>Cannot open database &quot;%1&quot; using connection &quot;%2&quot;: %3</source>
        <translation type="vanished">“%2” bağlantısı kullanılarak “%1” veritabanı açılamıyor: %3</translation>
    </message>
</context>
<context>
    <name>FilterNameDialogClass</name>
    <message>
        <source>Add Filter</source>
        <translation>Süzgeç Ekle</translation>
    </message>
    <message>
        <source>Filter Name:</source>
        <translation>Süzgeç adı:</translation>
    </message>
</context>
<context>
    <name>QHelpFilterSettingsWidget</name>
    <message>
        <source>Form</source>
        <translation>Form</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Süzgeç</translation>
    </message>
    <message>
        <source>Components</source>
        <translation>Bileşenler</translation>
    </message>
    <message>
        <source>Versions</source>
        <translation>Sürümler</translation>
    </message>
    <message>
        <source>Add...</source>
        <translation>Ekle…</translation>
    </message>
    <message>
        <source>Rename...</source>
        <translation>Yeniden Adlandır…</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Kaldır</translation>
    </message>
    <message>
        <source>Add Filter</source>
        <translation>Süzgeç Ekle</translation>
    </message>
    <message>
        <source>New Filter</source>
        <translation>Yeni Süzgeç</translation>
    </message>
    <message>
        <source>Rename Filter</source>
        <translation>Süzgeci Yeniden Adlandır</translation>
    </message>
    <message>
        <source>Remove Filter</source>
        <translation>Süzgeci Kaldır</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the &quot;%1&quot; filter?</source>
        <translation>“%1” süzgecini kaldırmak istediğinizden emin misiniz?</translation>
    </message>
    <message>
        <source>Filter Exists</source>
        <translation>Süzgeç Var</translation>
    </message>
    <message>
        <source>The filter &quot;%1&quot; already exists.</source>
        <translation>“%1” süzgeci halihazırda var.</translation>
    </message>
    <message>
        <source>No Component</source>
        <translation>Bileşen Yok</translation>
    </message>
    <message>
        <source>Invalid Component</source>
        <translation>Geçersiz Bileşen</translation>
    </message>
    <message>
        <source>No Version</source>
        <translation>Sürüm Yok</translation>
    </message>
    <message>
        <source>Invalid Version</source>
        <translation>Geçersiz Sürüm</translation>
    </message>
</context>
<context>
    <name>QOptionsWidget</name>
    <message>
        <source>No Option</source>
        <translation>Seçenek Yok</translation>
    </message>
    <message>
        <source>Invalid Option</source>
        <translation>Geçersiz Seçenek</translation>
    </message>
</context>
<context>
    <name>fulltextsearch::QHelpSearchIndexWriter</name>
    <message>
        <source>Cannot open database &quot;%1&quot; using connection &quot;%2&quot;: %3</source>
        <translation>“%2” bağlantısı kullanılarak “%1” veritabanı açılamıyor: %3</translation>
    </message>
</context>
</TS>
